summaryrefslogtreecommitdiffstatshomepage
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/genappimage.sh10
-rwxr-xr-xscripts/release.sh8
2 files changed, 9 insertions, 9 deletions
diff --git a/scripts/genappimage.sh b/scripts/genappimage.sh
index f8c567da57..29edc01950 100755
--- a/scripts/genappimage.sh
+++ b/scripts/genappimage.sh
@@ -6,7 +6,7 @@
# For more information, see http://appimage.org/
########################################################################
-# App arch, used by generate_appimage.
+# App arch
if [ -z "$ARCH" ]; then
ARCH="$(arch)"
export ARCH
@@ -15,8 +15,8 @@ ARCH_OUTPUT=$ARCH
TAG=$1
-# App name, used by generate_appimage.
-APP=nvim
+# App name
+APP=io.neovim.nvim
ROOT_DIR="$(git rev-parse --show-toplevel)"
APP_BUILD_DIR="$ROOT_DIR/build"
@@ -54,7 +54,7 @@ chmod +x "$APP_BUILD_DIR"/linuxdeploy-"$ARCH".AppImage
# metainfo is not packaged automatically by linuxdeploy
mkdir -p "$APP_DIR/usr/share/metainfo/"
-cp "$ROOT_DIR/runtime/nvim.appdata.xml" "$APP_DIR/usr/share/metainfo/"
+cp "$ROOT_DIR/runtime/$APP.appdata.xml" "$APP_DIR/usr/share/metainfo/"
cd "$APP_DIR" || exit
@@ -93,7 +93,7 @@ fi
# - Expects: $ARCH, $APP, $VERSION env vars
# - Expects: ./$APP.AppDir/ directory
# - Produces: ./nvim-linux-$ARCH_OUTPUT.appimage
-./linuxdeploy-"$ARCH".AppImage --appdir $APP.AppDir -d "$ROOT_DIR"/runtime/nvim.desktop -i \
+./linuxdeploy-"$ARCH".AppImage --appdir $APP.AppDir -d "$ROOT_DIR/runtime/$APP.desktop" -i \
"$ROOT_DIR/runtime/nvim.png" --output appimage
# Moving the final executable to a different folder so it isn't in the
diff --git a/scripts/release.sh b/scripts/release.sh
index 72d0a58821..f7dd151efe 100755
--- a/scripts/release.sh
+++ b/scripts/release.sh
@@ -12,7 +12,7 @@
# - CMakeLists.txt: Unset NVIM_VERSION_PRERELEASE
# - CMakeLists.txt: Unset NVIM_API_PRERELEASE
# - Create test/functional/fixtures/api_level_N.mpack
# - Add date and version to runtime/nvim.appdata.xml
# - Tag the commit.
# Create the "version bump" commit:
# - CMakeLists.txt: Set NVIM_VERSION_PRERELEASE to "-dev"
@@ -64,8 +64,8 @@ _do_release_commit() {
fi
$__sed -i.bk 's,(<releases>),\1\
- <release date="'"${__DATE}"'" version="'"${__VERSION}"'"/>,' runtime/nvim.appdata.xml
- git add runtime/nvim.appdata.xml
+ <release date="'"${__DATE}"'" version="'"${__VERSION}"'"/>,' runtime/io.neovim.nvim.appdata.xml
+ git add runtime/io.neovim.nvim.appdata.xml
if ! test "$ARG1" = '--use-current-commit' ; then
echo "Building changelog since ${__LAST_TAG}..."
@@ -81,7 +81,7 @@ _do_bump_commit() {
$__sed -i.bk 's/(NVIM_VERSION_PRERELEASE) ""/\1 "-dev"/' CMakeLists.txt
$__sed -i.bk 's/set\((NVIM_VERSION_PATCH) [[:digit:]]/set(\1 ?/' CMakeLists.txt
rm -f CMakeLists.txt.bk
- rm -f runtime/nvim.appdata.xml.bk
+ rm -f runtime/io.neovim.nvim.appdata.xml.bk
nvim +'/NVIM_VERSION' +1new +'exe "norm! iUpdate version numbers!!!"' \
-O CMakeLists.txt
@@ -12,7 +12,7 @@
# - CMakeLists.txt: Unset NVIM_API_PRERELEASE
# - Create test/functional/fixtures/api_level_N.mpack
-# - Add date and version to runtime/nvim.appdata.xml
+# - Add date and version to runtime/io.neovim.nvim.appdata.xml
# - Tag the commit.
# Create the "version bump" commit: